==============================
EC2API Metadata configuration
==============================

Configuration options
~~~~~~~~~~~~~~~~~~~~~

To configure Metadata Service for ec2api, EC2 API configuration_ common sections
 (such as OpenStack Clients, Database Client, EC2API and Common sections)
 must be configured as well.

.. _configuration: ./api.html

The additional configuration options for EC2 Metadata:

.. include:: ./tables/ec2api-metadata.inc
